(function() {
	// Load plugin specific language pack
	tinymce.PluginManager.requireLangPack('davidsultraquicktags');

	tinymce.create('tinymce.plugins.DavidsUltraQuicktags', {
		/**
		 * Initializes the plugin, this will be executed after the plugin has been created.
		 * This call is done before the editor instance has finished it's initialization so use the onInit event
		 * of the editor instance to intercept that event.
		 *
		 * @param {tinymce.Editor} ed Editor instance that the plugin is initialized in.
		 * @param {string} url Absolute URL to where the plugin is located.
		 */
		init : function(ed, url) {
			entity_encoding : "raw";
			if ( typeof DVGButtonClick == 'undefined' ) return;

			ed.addButton('dvgamazonlink', {
				title : 'Link directly to a product by its ASIN or ISBN.',
				image : url + '/../../buttons/amazonlink.png',
				onclick : function() {
					DVGButtonClick('amazonlink');
				}
			});
			ed.addButton('dvgamazonsearch', {
				title : 'Enter a term to use for an Amazon search.',
				image : url + '/../../buttons/amazonsearch.png',
				onclick : function() {
					DVGButtonClick('amazonsearch');
				}
			});
			ed.addButton('dvgspan', {
				title : 'Add a custom span tag.',
				image : url + '/../../buttons/span.png',
				onclick : function() {
					DVGButtonClick('dvgspan');
				}
			});
			ed.addButton('dvgdiv', {
				title : 'Add a custom div tag.',
				image : url + '/../../buttons/div.png',
				onclick : function() {
					DVGButtonClick('dvgdiv');
				}
			});
		},

		/**
		 * Creates control instances based in the incomming name. This method is normally not
		 * needed since the addButton method of the tinymce.Editor class is a more easy way of adding buttons
		 * but you sometimes need to create more complex controls like listboxes, split buttons etc then this
		 * method can be used to create those.
		 *
		 * @param {String} n Name of the control to create.
		 * @param {tinymce.ControlManager} cm Control manager to use inorder to create new control.
		 * @return {tinymce.ui.Control} New control instance or null if no control was created.
		 */
		createControl : function(n, cm) {
			return null;
		},

		/**
		 * Returns information about the plugin as a name/value array.
		 * The current keys are longname, author, authorurl, infourl and version.
		 *
		 * @return {Object} Name/value array containing information about the plugin.
		 */
		getInfo : function() {
			return {
				longname : "David's Ultra Quicktags",
				author : 'David Vincent Gagne',
				authorurl : 'http://www.davidgagne.net/',
				infourl : 'http://www.davidgagne.net/tags/plugins/',
				version : "6.0"
			};
		}
	});

	// Register plugin
	tinymce.PluginManager.add('davidsultraquicktags', tinymce.plugins.DavidsUltraQuicktags);
})();